@@ -21,7 +21,7 @@ import ConfigParser, copy, curses, sys, getopt, exceptions, os.path, types, re,
 import log, version
 
 
-class ConfigError(exceptions.Exception):
+class ConfigError(Exception):
     pass
 
 
@@ -294,7 +294,10 @@ class configalternatives(configitem):
 
 class configpath(configitem):
     def _convert(self, s):
-        return os.path.expanduser(s)
+        if s != "":
+            return os.path.normpath(os.path.expanduser(s))
+        else:
+            return ""
 
 
 class confignetworklocation(configitem):
@@ -379,11 +382,13 @@ class general(configsection):
     plugins = configlist("")
 
 class database(configsection):
+    requestcachesize = configint("50000")
     class __template__(configsection):
         type = configalternatives("local", ["local", "remote"])
+        # the next two options will be removed in the future!
         basename = configpath("~/.pytone/mp3")
-        dbenvdir = configpath("~/.pytone/mp3")
         dbfile = configpath("")
+        dbenvdir = configpath("~/.pytone/mp3")
         cachesize = configint("1000")
         musicbasedir = configpath("")
         tracknrandtitlere = configre(r"^\[?(\d+)\]? ?[- ] ?(.*)\.(mp3|ogg)$")
@@ -479,13 +484,17 @@ class mixerwindow(configsection):
 
 
 class helpwindow(configsection):
-    autoclosetime = configfloat("10")
+    autoclosetime = configfloat("0")
 
 
 class logwindow(configsection):
     autoclosetime = configfloat("10")
 
 
+class statswindow(configsection):
+    autoclosetime = configfloat("10")
+
+
 class iteminfolongwindow(configsection):
     autoclosetime = configfloat("10")
 
@@ -590,6 +599,14 @@ class colors(configsection):
         activeborder = configcolor("color brightgreen mono bold")
         border = configcolor("color green")
 
+    class statswindow(configsection):
+        title = configcolor("color brightgreen mono bold")
+        content = configcolor("color white")
+        background = configcolor("color white")
+        description = configcolor("color brightcyan mono bold")
+        activeborder = configcolor("color brightgreen mono bold")
+        border = configcolor("color green")
+
     class statusbar(configsection):
         key = configcolor("color brightcyan mono bold")
         background = configcolor("color white")
@@ -616,10 +633,14 @@ class keybindings(configsection):
         togglelayout = configkeys("KEY_F10")
         showhelp = configkeys("?")
         showlog = configkeys("!")
+        showstats = configkeys("%")
         showiteminfolong = configkeys("=")
         toggleiteminfowindow = configkeys("ctrl-v")
         volumeup = configkeys(")")
         volumedown = configkeys("(")
+        playerplayfaster = configkeys("}")
+        playerplayslower = configkeys("{")
+        playerspeedreset = configkeys("~")
 
     class filelistwindow(configsection):
         selectnext = configkeys("KEY_DOWN j")
@@ -660,7 +681,7 @@ class keybindings(configsection):
 #
 
 sections = ['mixerwindow', 'helpwindow', 'filelistwindow', 'database', 'iteminfowindow',
-            'logwindow', 'iteminfolongwindow', 'mixer', 'colors', 'playerwindow', 'playlistwindow',
+            'logwindow', 'statswindow', 'iteminfolongwindow', 'mixer', 'colors', 'playerwindow', 'playlistwindow',
             'general', 'inputwindow', 'network', 'player', 'keybindings']
 
 ##############################################################################
@@ -735,7 +756,7 @@ def processstandardconfig():
                     mainsection, subsection = section.split(".")
                 except:
                     raise ConfigError("Unkown configuration section '%s'" % section)
-                if mainsection not in sections or not subsection.isalpha():
+                if mainsection not in sections or not subsection.isalnum():
                     raise ConfigError("Unkown configuration section '%s'" % section)
                 # get corresponding config class
                 try:
@@ -867,22 +888,23 @@ def checkoptions():
                     "to the location of your MP3/Ogg Vorbis files." % databasename )
             sys.exit(2)
 
-        if songdb.type=="local" and not (songdb.dbfile != "" and songdb.basename == "" or
-                                         songdb.dbfile == "" and songdb.basename != ""):
-            print "Please use either the dbfile or the basename option (not both) to specify the location of your song database '%s'." % databasename
-            sys.exit(2)
-
         if songdb.basename != "":
             if songdb.basename in basenames:
                 print "basename '%s' of database '%s' already in use." % (songdb.basename, databasename)
                 sys.exit(2)
             basenames.append(songdb.basename)
 
-        if songdb.dbfile != "":
-            if songdb.dbenvdir in dbenvdirs:
-                print "dbenvdir '%s' of database '%s' already in use." % (songdb.dbenvdir, databasename)
+        if songdb.dbenvdir in dbenvdirs:
+            print "dbenvdir '%s' of database '%s' already in use." % (songdb.dbenvdir, databasename)
+            sys.exit(2)
+        dbenvdirs.append(songdb.dbenvdir)
+
+        if songdb.dbfile:
+            if songdb.dbfile == "db":
+                log.warning(_('using dbfile="db" by default, please remove dbfile entry in [database.%s] section of your config file') % databasename)
+            else:
+                print "setting dbfile not possible anymore, please move dbfile of database '%s'" % databasename
                 sys.exit(2)
-            dbenvdirs.append(songdb.dbenvdir)
 
     # check whether oss module is present
     try:
