@@ -55,11 +55,15 @@ descriptions = {
           "playlistload":      (_("load"), _("load playlist")),
           "showhelp":          (_("help"), _("show help")),
           "showlog":           (_("log"), _("show log messages")),
+          "showstats":         (_("statistics"), _("show statistical information about database(s)")),
           "showiteminfolong":  (_("item info"), _("show information about selected item")),
           "toggleiteminfowindow":  (_("toggle item info"), _("toggle information shown in item info window")),
           "togglelayout":      (_("toggle layout"), _("toggle layout")),
           "volumeup":          (_("volume up"), _("increase output volume")),
           "volumedown":        (_("volume down"), _("decrease output volume")),
+          "playerplayfaster":  (_("play faster"), _("increase the play speed")),
+          "playerplayslower":  (_("play slower"), _("decrease the play speed")),
+          "playerspeedreset":  (_("default play speed"), _("reset the play speed to normal")),
     },
     "filelistwindow": {
           "selectnext":        (_("down"), _("move to the next entry")),
@@ -99,7 +103,7 @@ descriptions = {
           }
     }
 
-# prefill keynames 
+# prefill keynames
 keynames = {}
 for c in range(32):
     keynames[c] = _("CTRL")+"-"+chr(c+64)
@@ -120,18 +124,23 @@ keynames[curses.KEY_ENTER]     = _("<Enter>")
 keynames[curses.KEY_HOME]      = _("<Home>")
 keynames[curses.KEY_IC]        = _("<Insert>")
 keynames[curses.KEY_LEFT]      = _("<Left>")
+keynames[curses.KEY_SLEFT]     = _("<Shift-Left>")
 keynames[curses.KEY_NPAGE]     = _("<PageDown>")
 keynames[curses.KEY_PPAGE]     = _("<PageUp>")
 keynames[curses.KEY_RIGHT]     = _("<Right>")
+keynames[curses.KEY_SRIGHT]    = _("<Shift-Right>")
 keynames[curses.KEY_UP]        = _("<Up>")
 
 # function keys
-for nr in range(1, 13):
+for nr in range(1, 23):
     keynames[eval("curses.KEY_F%d" % nr)] = "<F%d>" %nr
 
-
 # alt+key
 for key in keynames.keys():
-    keynames[key+1024] = _("ALT")+"-"+keynames[key]
-
+    keynames[key+1024] = "%s-%s"% (_("Alt"), keynames[key])
 
+def getkeyname(key):
+    try:
+        return keynames[key]
+    except KeyError:
+        return "Key_%d" % key 
