@@ -162,7 +162,7 @@ try:
             pluginconfig = pluginconfig()
             plugins.append((pluginmodule, pluginconfig))
         except Exception, e:
-             log.error(_("Cannot load plugin '%s': %s" % (name, e)))
+             log.error(_("Cannot load plugin '%s': %s") % (name, e))
 except:
     # if something goes wrong, shutdown all already running services
     hub.notify(events.quit(), 100)
@@ -234,7 +234,7 @@ def cursessetup():
 
     # redirect stderr to /dev/null (to prevent spoiling the screen
     # with libalsa messages). This is not really nice but at the moment there
-    # is no other way to get rid of these nuisance.
+    # is no other way to get rid of this nuisance.
     dev_null = file("/dev/null", 'w')
     os.dup2(dev_null.fileno(), sys.stderr.fileno())
 
