@@ -27,9 +27,26 @@ import decoder
 from services.player import genericplayer
 import log
 
+try:
+    import bufferedao
+    import thread
+    bufferedao_present = True
+except ImportError:
+    bufferedao_present = False
+    try:
+        import ao
+        ao_present = True
+    except ImportError:
+        ao_present = False
+    try:
+        import ossaudiodev
+        ossaudiodev_present = False
+    except ImportError:
+        ossaudiodev_present = False
+    
+
 class aoaudiodev:
     def __init__(self, aodevice, rate, options):
-        import ao
         self.ao = ao.AudioDevice(aodevice, rate=rate, options=options)
 
     def play(self, buff, bytes):
@@ -43,7 +60,6 @@ class aoaudiodev:
 
 class ossaudiodev:
     def __init__(self, device, rate):
-        import ossaudiodev
         self.ossdevice = ossaudiodev.open(device, "w")
         if sys.byteorder == 'little':
             self.ossdevice.setfmt(ossaudiodev.AFMT_S16_LE)
@@ -85,10 +101,10 @@ class bufferedaudiodev(threading.Thread):
         while self.audiodev is None:
             try:
                 if self.aodevice=="oss":
-                    try:
+                    if ossaudiodev_present:
                         self.audiodev = ossaudiodev(self.aooptions["dsp"], self.rate)
                         log.debug("ossaudiodev audio device opened")
-                    except:
+                    else:
                         self.audiodev = aoaudiodev(self.aodevice, rate=self.rate, options=self.aooptions)
                         log.debug("ao audio device opened")
                 else:
@@ -123,17 +139,19 @@ class bufferedaudiodev(threading.Thread):
                     self.restart.wait()
                     self.restart.clear()
                 buff, bytes = self.queue.get(1)
-                if self.audiodev is None:
-                    self.opendevice()
                 if buff != 0 and bytes != 0:
-                    self.audiodev.play(buff, bytes)
+                    audiodev = self.audiodev
+                    while audiodev is None:
+                        self.opendevice()
+                        audiodev = self.audiodev
+                    audiodev.play(buff, bytes)
             except:
                 log.warning("exception occured in bufferedaudiodev")
                 log.debug_traceback()
 
     def play(self, buff, bytes):
         self.queue.put((buff, bytes))
-        
+
     def flush(self):
         while True:
             try:
@@ -146,8 +164,9 @@ class bufferedaudiodev(threading.Thread):
         self.closedevice()
 
     def unpause(self):
-        self.ispaused = False
-        self.restart.set()
+        if self.ispaused:
+            self.ispaused = False
+            self.restart.set()
 
     def quit(self):
         self.done = True
@@ -163,9 +182,16 @@ class player(genericplayer):
         self.rate = 44100
         self.SIZE = 4096
 
-        # create audio device thread
-        self.audiodev = bufferedaudiodev(aodevice, aooptions, bufsize, self.rate, self.SIZE)
-        self.audiodev.start()
+        # use C version of buffered audio device if present
+        if bufferedao_present:
+            self.audiodev = bufferedao.bufferedao(bufsize, self.SIZE, aodevice, rate=self.rate, options=aooptions)
+            # we have to start a new thread for the bufferedao device
+            thread.start_new(self.audiodev.start, ())
+            log.debug("bufferedao device opened")
+        else:
+            # create audio device thread
+            self.audiodev = bufferedaudiodev(aodevice, aooptions, bufsize, self.rate, self.SIZE)
+            self.audiodev.start()
 
         # songs currently playing
         self.songs = []
@@ -194,8 +220,7 @@ class player(genericplayer):
         """decode songs and mix them together"""
 
         # unpause buffered ao if necessary
-        if self.audiodev.ispaused:
-            self.audiodev.unpause()
+        self.audiodev.unpause()
 
         if len(self.songs) == 1:
             song = self.songs[0]
@@ -205,7 +230,7 @@ class player(genericplayer):
             else:
                 log.debug("internal player: song ends: %s (0 songs in queue)" % self.songs[0])
                 del self.songs[0]
-        
+
             # reset songtransition mode, but before possibly requesting a new song
             self.songtransitionmode = None
 
@@ -331,6 +356,18 @@ class player(genericplayer):
         song.seekrelative(seconds)
         self.audiodev.flush()
 
+    def _playerplayfaster(self):
+        if self.songs:
+            self.songs[0].playfaster()
+
+    def _playerplayslower(self):
+        if self.songs:
+            self.songs[0].playslower()
+
+    def _playerspeedreset(self):
+        if self.songs:
+            self.songs[0].resetplayspeed()
+
     def _playerreleasedevice(self):
         self.audiodev.closedevice()
 
