@@ -25,11 +25,11 @@ class slist:
 
     List with selectable items, out of which maximally height are
     being displayed at the same time.
-    
+
     If window corresponding to list has focus, selectionchanged events
     are issued upon change of the currently selected item.
     """
-    
+
     def __init__(self, win, pagescroll):
         self.win = win
         self.items = []
@@ -48,10 +48,10 @@ class slist:
     def __delitem__(self, index):
         del self.items[index]
         if self.selected is not None:
-            if len(self)==0:
+            if len(self) == 0:
                 self.selected = None
             else:
-                if index<self.selected:
+                if index < self.selected:
                     self.selected -= 1
                 self.selected = min(self.selected, len(self)-1)
             self._notifyselectionchanged()
@@ -83,17 +83,40 @@ class slist:
                 del self[i]
                 return
 
-    def set(self, items):
-        """set all items in slist"""
+    def set(self, items, keepselection=False):
+        """set all items in slist trying to keep the current selection if keepselection is set """
+        if keepselection:
+            oldselecteditem = self.getselected()
+            oldselected = self.selected
         try:
             self.items = list(items)
         except:
             self.items = []
-        if self.items:
-            self.selected = 0
+        if keepselection and oldselected is not None and self.items:
+            # we try to keep the current selection and search for the previously
+            # selected item in the new list. We most probably find it around
+            # the original position.
+            oldselecteditemid = oldselecteditem.getid()
+            startsearch = min(max(0, oldselected-1), len(self))
+            for i in range(startsearch, len(self)) + range(startsearch):
+                if self[i].getid() == oldselecteditemid:
+                    self.selected = i
+                    break
+            else:
+                # if this fails (typically because the song has been
+                # deleted from the playlist), we take the item at the
+                # last selected position, if possible
+                if oldselected < len(self):
+                    self.selected = oldselected
+                elif len(self) > 0:
+                    self.selected = len(self)-1
+            self._updatetop()
         else:
-            self.selected = None
-        self.top = 0
+            if self.items:
+                self.selected = 0
+            else:
+                self.selected = None
+            self.top = 0
         self._notifyselectionchanged()
 
     def sort(self, func=None):
@@ -111,14 +134,14 @@ class slist:
 
         if self.win.hasfocus():
             hub.notify(events.selectionchanged(self.getselected()))
-    
+
     def _updatetop(self):
         "helper routine, which updates self.top"
-        
+
         if len(self)<=self.win.ih:
             self.top = 0
             return
-        
+
         if self.selected is not None and self.selected<self.top:
             if self.pagescroll:
                 self.top = max(0, self.selected-self.win.ih+1)
@@ -174,93 +197,103 @@ class slist:
         self.selected = nr
         self._notifyselectionchanged()
         self._updatetop()
-            
+
+    def selectbylinenumber(self, nr):
+        """select entry by line number in window
+        Returns True if selection was valid, otherwise False.
+        """
+        if len(self) > 0:
+            if nr >= 0 and self.top+nr < len(self):
+                self.selected = self.top+nr
+                self._notifyselectionchanged()
+                return True
+        return False
+
+    def selectbyname(self, name):
+        """select entry by name
+        Returns True if selection was valid, otherwise False."""
+        if len(self) > 0:
+            for i in range(len(self)):
+                if self[i].name == name:
+                    self.selected = i
+                    self._notifyselectionchanged()
+                    self._updatetop()
+                    return True
+        return False
+
     def selectbysearchstring(self, searchstring):
-        "select next entry matching searchstring"
-        if len(self)>0:
+        """select next entry matching searchstring.
+        Returns True if selection was valid, otherwise False."""
+        if len(self) > 0:
             searchstring = searchstring.lower()
-            
             if self.selected is None:
                 first = 0
             else:
                 first = self.selected
-                
             for i in range(first+1, len(self)) + range(first):
                 if self[i].getname().lower().find(searchstring)!=-1:
                     self.selected = i
                     self._notifyselectionchanged()
                     self._updatetop()
-                    break
+                    return True
+        return False
 
     def selectbyregexp(self, regexp, includeselected=True):
-        "select next entry matching regexp"
-
-        if len(self)>0:
+        """select next entry matching regexp
+        Returns True if selection was valid, otherwise False."""
+        if len(self) > 0:
             try:
                 cregexp = re.compile(regexp, re.IGNORECASE)
             except:
                 return
-            
             if self.selected is None:
                 first = 0
             else:
                 first = self.selected
-            
             for i in range(first + (not includeselected and 1 or 0), len(self)) + range(first):
                 if cregexp.search(self[i].getname()):
                     self.selected = i
                     self._notifyselectionchanged()
                     self._updatetop()
-                    break
+                    return True
+        return False
 
     def selectbyletter(self, letter):
-        "select next entry beginning with letter"
+        """select next entry beginning with letter
+        Returns True if selection was valid, otherwise False."""
         if len(self)>0:
             if self.selected is None:
                 first = 0
             else:
                 first = self.selected
                 letter = letter.lower()
-            
                 for i in range(first+1, len(self)) + range(first):
                     if self[i].getname().lower().startswith(letter):
                         self.selected = i
                         self._notifyselectionchanged()
                         self._updatetop()
-                        break
-
-    def selectbylinenumber(self, nr):
-        """select entry by line number in window
-
-        returns 1 if selection was valid, otherwise 0
-        """
-        
-        if len(self)>0:
-            if nr>=0 and self.top+nr<len(self):
-                self.selected = self.top+nr
-                self._notifyselectionchanged()
-                return 1
-        return 0
+                        return True
+        return False
 
     def selectrelative(self, dist):
         "change selection relatively by dist"
-        if len(self)>0:
+        if len(self) > 0:
             self.selected += dist
             self.selected = max(self.selected,0)
             self.selected = min(self.selected, len(self)-1)
             self._notifyselectionchanged()
             self._updatetop()
-                
+
     def selectfirst(self):
         "select first item of list"
-        if len(self)>0:
+        if len(self) > 0:
             self.selected = 0
             self._notifyselectionchanged()
             self._updatetop()
-            
+
     def selectlast(self):
         "select last item of list"
-        if len(self)>0:
+        if len(self) > 0:
             self.selected = len(self)-1
             self._notifyselectionchanged()
             self._updatetop()
@@ -275,22 +308,21 @@ class slist:
 
     def selectnextpage(self):
         "select next page of list"
-
         self.selectrelative(self.win.ih)
 
     def selectprevpage(self):
         "select previous page of list"
-        if len(self)>0:
-            if self.top-self.win.ih>=0:
+        if len(self) > 0:
+            if self.top-self.win.ih >= 0:
                 self.top = self.top-self.win.ih
                 self.selected = min(self.top+self.win.ih-1, len(self)-1)
             else:
                 self.top = self.selected = 0
             self._notifyselectionchanged()
-            
+
     def moveitemup(self):
         "move selected item up, if not first"
-        if self.selected is not None and self.selected>0:
+        if self.selected is not None and self.selected > 0:
             self.items[self.selected-1], self.items[self.selected] = \
             self.items[self.selected], self.items[self.selected-1]
             self.selected -= 1
@@ -298,10 +330,8 @@ class slist:
 
     def moveitemdown(self):
         "move selected item down, if not last"
-        if self.selected is not None and self.selected<len(self)-1:
+        if self.selected is not None and self.selected < len(self)-1:
             self.items[self.selected], self.items[self.selected+1] = \
             self.items[self.selected+1], self.items[self.selected]
             self.selected += 1
             self._updatetop()
-
-
